@@ -20,6 +20,6 @@ class Person(models.Model):
     address_street = models.CharField(_("street name"), max_length=255)
     address_number = models.CharField(_("house number"), max_length=10)
 
-    address = GegevensGroepType({"street": address_street, "number": address_number})
+    address = GegevensGroepType({"street": address_street, "number": address_number}, required=False)
 
     group = models.ForeignKey("Group", null=True, on_delete=models.CASCADE)
