@@ -3,5 +3,5 @@ from django.utils.translation import ugettext_lazy as _
 
 
 class NotificationsConfig(AppConfig):
-    name = 'vng_api_common.notifications'
+    name = "vng_api_common.notifications"
     verbose_name = _("Notificaties")
